---
name: Bug report
about: Create a report to help us improve
title: ''
labels: needs-triage
assignees: ''

---

# Describe the bug
A clear and concise description of what the bug is.


# Expected behavior
A clear and concise description of what you expected to happen.


# To Reproduce
Steps to reproduce the behavior:

1. …
2. …
3. …


# Environments
Please execute the following command and past the output:

```
pip install envinfopy[markdown]
python -m envinfopy tcconfig docker SimpleSQLite --format markdown
```

and complete the following information:

- **Docker Version (if you using docker)**: ...
- **Installation Method**: `pip` / `deb package`


# Additional context
Add any other context (logs, error output, etc.) about the problem here.
